# Add Organizations
### On this page
  * [Introduction to Organizations](https://help.sap.com/docs/leanix/ea/add-organizations#introduction-to-organizations)
  * [Required Attributes](https://help.sap.com/docs/leanix/ea/add-organizations#required-attributes)
  * [Define Organizations](https://help.sap.com/docs/leanix/ea/add-organizations#define-organizations)
  * [Add Organizations](https://help.sap.com/docs/leanix/ea/add-organizations#add-organizations)
  * [Monitor Progress Using Metrics](https://help.sap.com/docs/leanix/ea/add-organizations#monitor-progress-using-metrics)


Define and import an initial set of organizations into your workspace.
